# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/topic/v1/topic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2
from bilireq.grpc.protos.bilibili.app.card.v1 import common_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_common__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/topic/v1/topic.proto\x12\x15\x62ilibili.app.topic.v1\x1a%bilibili/app/dynamic/v2/dynamic.proto\x1a!bilibili/app/card/v1/common.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"(\n\nButtonMeta\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\"\xaf\x03\n\x0e\x44\x65tailsTopInfo\x12\x34\n\ntopic_info\x18\x01 \x01(\x0b\x32 .bilibili.app.topic.v1.TopicInfo\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.bilibili.app.topic.v1.User\x12\x12\n\nstats_desc\x18\x03 \x01(\t\x12\x1f\n\x17has_create_jurisdiction\x18\x04 \x01(\x08\x12\x42\n\x11operation_content\x18\x05 \x01(\x0b\x32\'.bilibili.app.topic.v1.OperationContent\x12\x14\n\x0chead_img_url\x18\x06 \x01(\t\x12\x1a\n\x12head_img_backcolor\x18\x07 \x01(\t\x12\x12\n\nword_color\x18\x08 \x01(\x05\x12\x1e\n\x16mission_page_show_type\x18\t \x01(\x05\x12\x13\n\x0bmission_url\x18\n \x01(\t\x12\x14\n\x0cmission_text\x18\x0b \x01(\t\x12\x32\n\ttopic_set\x18\x0c \x01(\x0b\x32\x1f.bilibili.app.topic.v1.TopicSet\"c\n\x0c\x46oldCardItem\x12\x14\n\x0cis_show_fold\x18\x01 \x01(\x05\x12\x12\n\nfold_count\x18\x02 \x01(\x03\x12\x16\n\x0e\x63\x61rd_show_desc\x18\x03 \x01(\t\x12\x11\n\tfold_desc\x18\x04 \x01(\t\"\xb5\x01\n\x0e\x46unctionalCard\x12\x35\n\x08\x63\x61psules\x18\x01 \x03(\x0b\x32#.bilibili.app.topic.v1.TopicCapsule\x12\x38\n\x0ctraffic_card\x18\x02 \x01(\x0b\x32\".bilibili.app.topic.v1.TrafficCard\x12\x32\n\tgame_card\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.topic.v1.GameCard\"\x86\x01\n\x08GameCard\x12\x0f\n\x07game_id\x18\x01 \x01(\x03\x12\x11\n\tgame_icon\x18\x02 \x01(\t\x12\x11\n\tgame_name\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\t\x12\x11\n\tgame_tags\x18\x05 \x01(\t\x12\x0e\n\x06notice\x18\x06 \x01(\t\x12\x11\n\tgame_link\x18\x07 \x01(\t\"i\n\x11InlineProgressBar\x12\x11\n\ticon_drag\x18\x01 \x01(\t\x12\x16\n\x0eicon_drag_hash\x18\x02 \x01(\t\x12\x11\n\ticon_stop\x18\x03 \x01(\t\x12\x16\n\x0eicon_stop_hash\x18\x04 \x01(\t\"\xb9\x04\n\x10LargeCoverInline\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x18\n\x10\x63over_left_text1\x18\x02 \x01(\t\x12\x18\n\x10\x63over_left_icon1\x18\x03 \x01(\x05\x12\x18\n\x10\x63over_left_text2\x18\x04 \x01(\t\x12\x18\n\x10\x63over_left_icon2\x18\x05 \x01(\x05\x12\x46\n\x14right_top_live_badge\x18\x06 \x01(\x0b\x32(.bilibili.app.topic.v1.RightTopLiveBadge\x12\x11\n\textra_uri\x18\x07 \x01(\t\x12\x45\n\x13inline_progress_bar\x18\x08 \x01(\x0b\x32(.bilibili.app.topic.v1.InlineProgressBar\x12\x41\n\x11topic_three_point\x18\t \x01(\x0b\x32&.bilibili.app.topic.v1.TopicThreePoint\x12\x17\n\x0f\x63over_left_desc\x18\n \x01(\t\x12\x19\n\x11hide_danmu_switch\x18\x0b \x01(\x08\x12\x15\n\rdisable_danmu\x18\x0c \x01(\x08\x12\x10\n\x08\x63\x61n_play\x18\r \x01(\x05\x12\x15\n\rduration_text\x18\x0e \x01(\t\x12:\n\rrelation_data\x18\x0f \x01(\x0b\x32#.bilibili.app.topic.v1.RelationData\"\xd2\x01\n\x11LiveBadgeResource\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\ranimation_url\x18\x02 \x01(\t\x12\x1a\n\x12\x61nimation_url_hash\x18\x03 \x01(\t\x12\x1e\n\x16\x62\x61\x63kground_color_light\x18\x04 \x01(\t\x12\x1e\n\x16\x62\x61\x63kground_color_night\x18\x05 \x01(\t\x12\x13\n\x0b\x61lpha_light\x18\x06 \x01(\x03\x12\x13\n\x0b\x61lpha_night\x18\x07 \x01(\x03\x12\x12\n\nfont_color\x18\x08 \x01(\t\"^\n\rOperationCard\x12\x45\n\x12large_cover_inline\x18\x01 \x01(\x0b\x32\'.bilibili.app.topic.v1.LargeCoverInlineH\x00\x42\x06\n\x04\x63\x61rd\"P\n\x10OperationContent\x12<\n\x0eoperation_card\x18\x01 \x01(\x0b\x32$.bilibili.app.topic.v1.OperationCard\"\x87\x01\n\x08PubLayer\x12\x11\n\tshow_type\x18\x01 \x01(\x05\x12\x11\n\tjump_link\x18\x02 \x01(\t\x12\x36\n\x0b\x62utton_meta\x18\x03 \x01(\x0b\x32!.bilibili.app.topic.v1.ButtonMeta\x12\x1d\n\x15\x63lose_pub_layer_entry\x18\x04 \x01(\x08\"g\n\x0cRelationData\x12\x0e\n\x06is_fav\x18\x01 \x01(\x08\x12\x0f\n\x07is_coin\x18\x02 \x01(\x08\x12\x11\n\tis_follow\x18\x03 \x01(\x08\x12\x0f\n\x07is_like\x18\x04 \x01(\x08\x12\x12\n\nlike_count\x18\x05 \x01(\x03\"|\n\x11RightTopLiveBadge\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x39\n\x07in_live\x18\x02 \x01(\x0b\x32(.bilibili.app.topic.v1.LiveBadgeResource\x12\x17\n\x0flive_stats_desc\x18\x03 \x01(\t\"1\n\x0bSortContent\x12\x0f\n\x07sort_by\x18\x01 \x01(\x03\x12\x11\n\tsort_name\x18\x02 \x01(\t\"1\n\x0eThreePointItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"W\n\x0eTimeLineEvents\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\ttime_desc\x18\x03 \x01(\t\x12\x11\n\tjump_link\x18\x04 \x01(\t\"\x94\x01\n\x10TimeLineResource\x12\x14\n\x0ctime_line_id\x18\x01 \x01(\x03\x12\x17\n\x0ftime_line_title\x18\x02 \x01(\t\x12?\n\x10time_line_events\x18\x03 \x03(\x0b\x32%.bilibili.app.topic.v1.TimeLineEvents\x12\x10\n\x08has_more\x18\x04 \x01(\x08\"a\n\x0fTopicActivities\x12\x36\n\x08\x61\x63tivity\x18\x01 \x03(\x0b\x32$.bilibili.app.topic.v1.TopicActivity\x12\x16\n\x0e\x61\x63t_list_title\x18\x02 \x01(\t\"_\n\rTopicActivity\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_name\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x10\n\x08icon_url\x18\x04 \x01(\t\"@\n\x0cTopicCapsule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x10\n\x08icon_url\x18\x03 \x01(\t\"\xe0\x01\n\rTopicCardItem\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12:\n\x0c\x64ynamic_item\x18\x02 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12;\n\x0e\x66ord_card_item\x18\x03 \x01(\x0b\x32#.bilibili.app.topic.v1.FoldCardItem\x12H\n\x15video_small_card_item\x18\x04 \x01(\x0b\x32).bilibili.app.topic.v1.VideoSmallCardItem\"\xb5\x01\n\rTopicCardList\x12>\n\x10topic_card_items\x18\x01 \x03(\x0b\x32$.bilibili.app.topic.v1.TopicCardItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x42\n\x12topic_sort_by_conf\x18\x04 \x01(\x0b\x32&.bilibili.app.topic.v1.TopicSortByConf\"\xd8\x03\n\x14TopicDetailsAllReply\x12?\n\x10\x64\x65tails_top_info\x18\x01 \x01(\x0b\x32%.bilibili.app.topic.v1.DetailsTopInfo\x12@\n\x10topic_activities\x18\x02 \x01(\x0b\x32&.bilibili.app.topic.v1.TopicActivities\x12=\n\x0ftopic_card_list\x18\x03 \x01(\x0b\x32$.bilibili.app.topic.v1.TopicCardList\x12>\n\x0f\x66unctional_card\x18\x04 \x01(\x0b\x32%.bilibili.app.topic.v1.FunctionalCard\x12\x32\n\tpub_layer\x18\x05 \x01(\x0b\x32\x1f.bilibili.app.topic.v1.PubLayer\x12\x43\n\x12time_line_resource\x18\x06 \x01(\x0b\x32\'.bilibili.app.topic.v1.TimeLineResource\x12\x45\n\x13topic_server_config\x18\x07 \x01(\x0b\x32(.bilibili.app.topic.v1.TopicServerConfig\"\xf9\x01\n\x12TopicDetailsAllReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x0f\n\x07sort_by\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\nlocal_time\x18\x05 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x06 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0cneed_refresh\x18\x07 \x01(\x05\x12\x0e\n\x06source\x18\x08 \x01(\t\x12\x1e\n\x16topic_details_ext_mode\x18\t \x01(\x05\"j\n\x15TopicDetailsFoldReply\x12=\n\x0ftopic_card_list\x18\x01 \x01(\x0b\x32$.bilibili.app.topic.v1.TopicCardList\x12\x12\n\nfold_count\x18\x02 \x01(\x03\"\xb9\x01\n\x13TopicDetailsFoldReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\nlocal_time\x18\x04 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0c\x66rom_sort_by\x18\x06 \x01(\x03\"\xf0\x02\n\tTopicInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x0c\n\x04view\x18\x04 \x01(\x03\x12\x0f\n\x07\x64iscuss\x18\x05 \x01(\x03\x12\x0b\n\x03\x66\x61v\x18\x06 \x01(\x03\x12\x10\n\x08\x64ynamics\x18\x07 \x01(\x03\x12\r\n\x05state\x18\x08 \x01(\x05\x12\x10\n\x08jump_url\x18\t \x01(\t\x12\x11\n\tbackcolor\x18\n \x01(\t\x12\x0e\n\x06is_fav\x18\x0b \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12\x15\n\rcreate_source\x18\r \x01(\x05\x12\x11\n\tshare_pic\x18\x0e \x01(\t\x12\r\n\x05share\x18\x0f \x01(\x03\x12\x0c\n\x04like\x18\x10 \x01(\x03\x12\x11\n\tshare_url\x18\x11 \x01(\t\x12\x0f\n\x07is_like\x18\x12 \x01(\x08\x12\x0c\n\x04type\x18\x13 \x01(\x05\x12\x12\n\nstats_desc\x18\x14 \x01(\t\x12\x18\n\x10\x66ixed_topic_icon\x18\x15 \x01(\t\"\x89\x01\n\x11TopicServerConfig\x12%\n\x1dpub_events_increase_threshold\x18\x01 \x01(\x03\x12+\n#pub_events_hidden_timeout_threshold\x18\x02 \x01(\x03\x12 \n\x18vert_online_refresh_time\x18\x03 \x01(\x03\"L\n\x08TopicSet\x12\x0e\n\x06set_id\x18\x01 \x01(\x03\x12\x10\n\x08set_name\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\"\xee\x01\n\x14TopicSetDetailsReply\x12\x44\n\x13topic_set_head_info\x18\x01 \x01(\x0b\x32\'.bilibili.app.topic.v1.TopicSetHeadInfo\x12\x34\n\ntopic_info\x18\x02 \x03(\x0b\x32 .bilibili.app.topic.v1.TopicInfo\x12\x10\n\x08has_more\x18\x03 \x01(\x08\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x38\n\x08sort_cfg\x18\x05 \x01(\x0b\x32&.bilibili.app.topic.v1.TopicSetSortCfg\"X\n\x12TopicSetDetailsReq\x12\x0e\n\x06set_id\x18\x01 \x01(\x03\x12\x0f\n\x07sort_by\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\xd8\x01\n\x10TopicSetHeadInfo\x12\x32\n\ttopic_set\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.topic.v1.TopicSet\x12\x16\n\x0etopic_cnt_text\x18\x02 \x01(\t\x12\x14\n\x0chead_img_url\x18\x03 \x01(\t\x12\x13\n\x0bmission_url\x18\x04 \x01(\t\x12\x14\n\x0cmission_text\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x0e\n\x06is_fav\x18\x07 \x01(\x08\x12\x15\n\ris_first_time\x18\x08 \x01(\x08\"c\n\x0fTopicSetSortCfg\x12\x17\n\x0f\x64\x65\x66\x61ult_sort_by\x18\x01 \x01(\x03\x12\x37\n\x0b\x61ll_sort_by\x18\x02 \x03(\x0b\x32\".bilibili.app.topic.v1.SortContent\"y\n\x0fTopicSortByConf\x12\x17\n\x0f\x64\x65\x66\x61ult_sort_by\x18\x01 \x01(\x03\x12\x37\n\x0b\x61ll_sort_by\x18\x02 \x03(\x0b\x32\".bilibili.app.topic.v1.SortContent\x12\x14\n\x0cshow_sort_by\x18\x03 \x01(\x03\"W\n\x0fTopicThreePoint\x12\x44\n\x15\x64yn_three_point_items\x18\x01 \x03(\x0b\x32%.bilibili.app.topic.v1.ThreePointItem\"\x8f\x01\n\x0bTrafficCard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\x12\x10\n\x08icon_url\x18\x03 \x01(\t\x12\x10\n\x08\x62\x61se_pic\x18\x04 \x01(\t\x12\x15\n\rbenefit_point\x18\x05 \x01(\t\x12\x11\n\tcard_desc\x18\x06 \x01(\t\x12\x12\n\njump_title\x18\x07 \x01(\t\"B\n\x04User\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tname_desc\x18\x04 \x01(\t\"l\n\rVideoCardBase\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07up_name\x18\x03 \x01(\t\x12\x0c\n\x04play\x18\x04 \x01(\x03\x12\x11\n\tjump_link\x18\x05 \x01(\t\x12\x0b\n\x03\x61id\x18\x06 \x01(\x03\"\xd6\x01\n\x12VideoSmallCardItem\x12=\n\x0fvideo_card_base\x18\x01 \x01(\x0b\x32$.bilibili.app.topic.v1.VideoCardBase\x12\x1d\n\x15\x63over_left_badge_text\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x61rd_stat_icon1\x18\x03 \x01(\x03\x12\x17\n\x0f\x63\x61rd_stat_text1\x18\x04 \x01(\t\x12\x17\n\x0f\x63\x61rd_stat_icon2\x18\x05 \x01(\x03\x12\x17\n\x0f\x63\x61rd_stat_text2\x18\x06 \x01(\t*N\n\rTopicCardType\x12\x10\n\x0cILLEGAL_TYPE\x10\x00\x12\x0b\n\x07\x44YNAMIC\x10\x01\x12\x08\n\x04\x46OLD\x10\x02\x12\x14\n\x10VIDEO_SMALL_CARD\x10\x03*7\n\x13TopicDetailsExtMode\x12\x15\n\x11MODE_ILLEGAL_TYPE\x10\x00\x12\t\n\x05STORY\x10\x01\x32\xcb\x02\n\x05Topic\x12i\n\x0fTopicDetailsAll\x12).bilibili.app.topic.v1.TopicDetailsAllReq\x1a+.bilibili.app.topic.v1.TopicDetailsAllReply\x12l\n\x10TopicDetailsFold\x12*.bilibili.app.topic.v1.TopicDetailsFoldReq\x1a,.bilibili.app.topic.v1.TopicDetailsFoldReply\x12i\n\x0fTopicSetDetails\x12).bilibili.app.topic.v1.TopicSetDetailsReq\x1a+.bilibili.app.topic.v1.TopicSetDetailsReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.topic.v1.topic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TOPICCARDTYPE']._serialized_start=6552
  _globals['_TOPICCARDTYPE']._serialized_end=6630
  _globals['_TOPICDETAILSEXTMODE']._serialized_start=6632
  _globals['_TOPICDETAILSEXTMODE']._serialized_end=6687
  _globals['_BUTTONMETA']._serialized_start=184
  _globals['_BUTTONMETA']._serialized_end=224
  _globals['_DETAILSTOPINFO']._serialized_start=227
  _globals['_DETAILSTOPINFO']._serialized_end=658
  _globals['_FOLDCARDITEM']._serialized_start=660
  _globals['_FOLDCARDITEM']._serialized_end=759
  _globals['_FUNCTIONALCARD']._serialized_start=762
  _globals['_FUNCTIONALCARD']._serialized_end=943
  _globals['_GAMECARD']._serialized_start=946
  _globals['_GAMECARD']._serialized_end=1080
  _globals['_INLINEPROGRESSBAR']._serialized_start=1082
  _globals['_INLINEPROGRESSBAR']._serialized_end=1187
  _globals['_LARGECOVERINLINE']._serialized_start=1190
  _globals['_LARGECOVERINLINE']._serialized_end=1759
  _globals['_LIVEBADGERESOURCE']._serialized_start=1762
  _globals['_LIVEBADGERESOURCE']._serialized_end=1972
  _globals['_OPERATIONCARD']._serialized_start=1974
  _globals['_OPERATIONCARD']._serialized_end=2068
  _globals['_OPERATIONCONTENT']._serialized_start=2070
  _globals['_OPERATIONCONTENT']._serialized_end=2150
  _globals['_PUBLAYER']._serialized_start=2153
  _globals['_PUBLAYER']._serialized_end=2288
  _globals['_RELATIONDATA']._serialized_start=2290
  _globals['_RELATIONDATA']._serialized_end=2393
  _globals['_RIGHTTOPLIVEBADGE']._serialized_start=2395
  _globals['_RIGHTTOPLIVEBADGE']._serialized_end=2519
  _globals['_SORTCONTENT']._serialized_start=2521
  _globals['_SORTCONTENT']._serialized_end=2570
  _globals['_THREEPOINTITEM']._serialized_start=2572
  _globals['_THREEPOINTITEM']._serialized_end=2621
  _globals['_TIMELINEEVENTS']._serialized_start=2623
  _globals['_TIMELINEEVENTS']._serialized_end=2710
  _globals['_TIMELINERESOURCE']._serialized_start=2713
  _globals['_TIMELINERESOURCE']._serialized_end=2861
  _globals['_TOPICACTIVITIES']._serialized_start=2863
  _globals['_TOPICACTIVITIES']._serialized_end=2960
  _globals['_TOPICACTIVITY']._serialized_start=2962
  _globals['_TOPICACTIVITY']._serialized_end=3057
  _globals['_TOPICCAPSULE']._serialized_start=3059
  _globals['_TOPICCAPSULE']._serialized_end=3123
  _globals['_TOPICCARDITEM']._serialized_start=3126
  _globals['_TOPICCARDITEM']._serialized_end=3350
  _globals['_TOPICCARDLIST']._serialized_start=3353
  _globals['_TOPICCARDLIST']._serialized_end=3534
  _globals['_TOPICDETAILSALLREPLY']._serialized_start=3537
  _globals['_TOPICDETAILSALLREPLY']._serialized_end=4009
  _globals['_TOPICDETAILSALLREQ']._serialized_start=4012
  _globals['_TOPICDETAILSALLREQ']._serialized_end=4261
  _globals['_TOPICDETAILSFOLDREPLY']._serialized_start=4263
  _globals['_TOPICDETAILSFOLDREPLY']._serialized_end=4369
  _globals['_TOPICDETAILSFOLDREQ']._serialized_start=4372
  _globals['_TOPICDETAILSFOLDREQ']._serialized_end=4557
  _globals['_TOPICINFO']._serialized_start=4560
  _globals['_TOPICINFO']._serialized_end=4928
  _globals['_TOPICSERVERCONFIG']._serialized_start=4931
  _globals['_TOPICSERVERCONFIG']._serialized_end=5068
  _globals['_TOPICSET']._serialized_start=5070
  _globals['_TOPICSET']._serialized_end=5146
  _globals['_TOPICSETDETAILSREPLY']._serialized_start=5149
  _globals['_TOPICSETDETAILSREPLY']._serialized_end=5387
  _globals['_TOPICSETDETAILSREQ']._serialized_start=5389
  _globals['_TOPICSETDETAILSREQ']._serialized_end=5477
  _globals['_TOPICSETHEADINFO']._serialized_start=5480
  _globals['_TOPICSETHEADINFO']._serialized_end=5696
  _globals['_TOPICSETSORTCFG']._serialized_start=5698
  _globals['_TOPICSETSORTCFG']._serialized_end=5797
  _globals['_TOPICSORTBYCONF']._serialized_start=5799
  _globals['_TOPICSORTBYCONF']._serialized_end=5920
  _globals['_TOPICTHREEPOINT']._serialized_start=5922
  _globals['_TOPICTHREEPOINT']._serialized_end=6009
  _globals['_TRAFFICCARD']._serialized_start=6012
  _globals['_TRAFFICCARD']._serialized_end=6155
  _globals['_USER']._serialized_start=6157
  _globals['_USER']._serialized_end=6223
  _globals['_VIDEOCARDBASE']._serialized_start=6225
  _globals['_VIDEOCARDBASE']._serialized_end=6333
  _globals['_VIDEOSMALLCARDITEM']._serialized_start=6336
  _globals['_VIDEOSMALLCARDITEM']._serialized_end=6550
  _globals['_TOPIC']._serialized_start=6690
  _globals['_TOPIC']._serialized_end=7021
# @@protoc_insertion_point(module_scope)



import hashlib
import random
import base64
import time
from typing import Optional

from ..._typing import T_Auth
from ..protos.bilibili.metadata.device.device_pb2 import Device
from ..protos.bilibili.metadata.locale.locale_pb2 import Locale
from ..protos.bilibili.metadata.metadata_pb2 import Metadata
from ..protos.bilibili.metadata.network.network_pb2 import Network, NetworkType
from ..protos.bilibili.metadata.fawkes.fawkes_pb2 import FawkesReq
from ..protos.bilibili.metadata.restriction.restriction_pb2 import Restriction, ModeType
from ..protos.bilibili.metadata.parabox.parabox_pb2 import Exps


def random_id():
    return "".join(random.sample("0123456789abcdefghijklmnopqrstuvwxyz", 8))


def fake_buvid():
    mac_list = []
    for _ in range(1, 7):
        rand_str = "".join(random.sample("0123456789abcdef", 2))
        mac_list.append(rand_str)
    rand_mac = ":".join(mac_list)
    md5 = hashlib.md5()
    md5.update(rand_mac.encode())
    md5_mac_str = md5.hexdigest()
    md5_mac = list(md5_mac_str)
    return f"XY{md5_mac[2]}{md5_mac[12]}{md5_mac[22]}{md5_mac_str}".upper()


def gen_aurora_eid(uid: int) -> str:
    if uid == 0:
        raise ValueError("uid must not be 0")
    result_byte = bytearray()
    mid_byte = bytearray(str(uid), "utf-8")
    key = bytearray(b"ad1va46a7lza")
    for i, v in enumerate(mid_byte):
        result_byte.append(v ^ key[i % len(key)])
    return base64.b64encode(result_byte).decode("utf-8").rstrip("=")


def gen_trace_id() -> str:
    random_id = "".join(random.choices("0123456789abcdefghijklmnopqrstuvwxyz", k=32))
    random_trace_id = random_id[:24]
    b_arr = [0] * 3
    ts = int(time.time())
    for i in reversed(range(3)):
        ts >>= 8
        b_arr[i] = ts % 256 if (ts // 128) % 2 == 0 else ts % 256 - 256
    for i in range(3):
        random_trace_id += "{:02x}".format(b_arr[i] & 0xFF)
    random_trace_id += random_id[-2:]
    return f"{random_trace_id}:{random_trace_id[16:]}:0:0"


BUVID = fake_buvid()


def make_metadata(auth: T_Auth = None, access_key: Optional[str] = None):
    if access_key:
        raise NotImplementedError("access_key is not supported yet")

    mid = 0
    if auth:
        from ...auth import Auth

        access_key = Auth(auth).access_token
        mid = Auth(auth).uid
    device_params = {
        "mobi_app": "android",
        "device": "phone",
        "build": 6550400,
        "channel": "bili",
        "buvid": BUVID,
        "platform": "android",
    }
    metadata_params = device_params.copy()
    if access_key:
        metadata_params["access_key"] = access_key
    metadata = {
        "x-bili-device-bin": Device(**device_params).SerializeToString(),
        "x-bili-local-bin": Locale().SerializeToString(),
        "x-bili-metadata-bin": Metadata(**metadata_params).SerializeToString(),
        "x-bili-network-bin": Network(type=NetworkType.WIFI).SerializeToString(),
        "x-bili-fawkes-request-bin": FawkesReq(
            appkey="android64", env="prod", session_id=random_id()
        ).SerializeToString(),
        "x-bili-restriction-bin": Restriction(
            teenagers_mode=False, lessons_mode=False, mode=ModeType.NORMAL, review=True, disable_rcmd=False
        ).SerializeToString(),
        "x-bili-exps-bin": Exps().SerializeToString(),
        "x-bili-aurora-zone": "",
        "x-bili-mid": str(mid).encode(),
        "x-bili-trace-id": gen_trace_id(),
        "buvid": BUVID,
    }
    if access_key:
        metadata["authorization"] = f"identify_v1 {access_key}"
        metadata["x-bili-aurora-eid"] = gen_aurora_eid(mid)
    return tuple(metadata.items())



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MidPrivacySettingsConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECOMMEND_TO_KNOWN_FIELD_NUMBER: builtins.int
    @property
    def recommend_to_known(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        recommend_to_known: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["recommend_to_known", b"recommend_to_known"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["recommend_to_known", b"recommend_to_known"]) -> None: ...

global___MidPrivacySettingsConfig = MidPrivacySettingsConfig

@typing_extensions.final
class PrivacySettingsConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AD_RECOMMAND_STORE_FIELD_NUMBER: builtins.int
    SENSOR_ACCESS_FIELD_NUMBER: builtins.int
    @property
    def ad_recommand_store(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def sensor_access(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """传感器权限"""
    def __init__(
        self,
        *,
        ad_recommand_store: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        sensor_access: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_recommand_store", b"ad_recommand_store", "sensor_access", b"sensor_access"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_recommand_store", b"ad_recommand_store", "sensor_access", b"sensor_access"]) -> None: ...

global___PrivacySettingsConfig = PrivacySettingsConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DynamicSelect(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLD_FIELD_NUMBER: builtins.int
    @property
    def fold(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        fold: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fold", b"fold"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fold", b"fold"]) -> None: ...

global___DynamicSelect = DynamicSelect

@typing_extensions.final
class Exp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def bucket(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int32Value:
        """"""
    def __init__(
        self,
        *,
        id: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        bucket: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int32Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "id", b"id"]) -> None: ...

global___Exp = Exp

@typing_extensions.final
class ExperimentalConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLAG_FIELD_NUMBER: builtins.int
    EXPS_FIELD_NUMBER: builtins.int
    @property
    def flag(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def exps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Exp]:
        """"""
    def __init__(
        self,
        *,
        flag: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        exps: collections.abc.Iterable[global___Exp] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["flag", b"flag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exps", b"exps", "flag", b"flag"]) -> None: ...

global___ExperimentalConfig = ExperimentalConfig

@typing_extensions.final
class MultipleTusConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_LEFT_FIELD_NUMBER: builtins.int
    DYNAMIC_SELECT_FIELD_NUMBER: builtins.int
    @property
    def top_left(self) -> global___TopLeft:
        """"""
    @property
    def dynamic_select(self) -> global___DynamicSelect:
        """"""
    def __init__(
        self,
        *,
        top_left: global___TopLeft | None = ...,
        dynamic_select: global___DynamicSelect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_select", b"dynamic_select", "top_left", b"top_left"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_select", b"dynamic_select", "top_left", b"top_left"]) -> None: ...

global___MultipleTusConfig = MultipleTusConfig

@typing_extensions.final
class TopLeft(google.protobuf.message.Message):
    """APP首页头像跳转信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    STORY_FOREGROUND_IMAGE_FIELD_NUMBER: builtins.int
    STORY_BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    LISTEN_FOREGROUND_IMAGE_FIELD_NUMBER: builtins.int
    LISTEN_BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    IOS_STORY_FOREGROUND_IMAGE_FIELD_NUMBER: builtins.int
    IOS_STORY_BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    IOS_LISTEN_FOREGROUND_IMAGE_FIELD_NUMBER: builtins.int
    IOS_LISTEN_BACKGROUND_IMAGE_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    URL_V2_FIELD_NUMBER: builtins.int
    GOTO_V2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    @property
    def url(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def story_foreground_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def story_background_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def listen_foreground_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def listen_background_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def ios_story_foreground_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def ios_story_background_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def ios_listen_foreground_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def ios_listen_background_image(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def goto(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def url_v2(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    @property
    def goto_v2(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def badge(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue:
        """"""
    def __init__(
        self,
        *,
        url: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        story_foreground_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        story_background_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        listen_foreground_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        listen_background_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        ios_story_foreground_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        ios_story_background_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        ios_listen_foreground_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        ios_listen_background_image: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        goto: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        url_v2: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
        goto_v2: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        badge: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.StringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge", b"badge", "goto", b"goto", "goto_v2", b"goto_v2", "ios_listen_background_image", b"ios_listen_background_image", "ios_listen_foreground_image", b"ios_listen_foreground_image", "ios_story_background_image", b"ios_story_background_image", "ios_story_foreground_image", b"ios_story_foreground_image", "listen_background_image", b"listen_background_image", "listen_foreground_image", b"listen_foreground_image", "story_background_image", b"story_background_image", "story_foreground_image", b"story_foreground_image", "url", b"url", "url_v2", b"url_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "goto", b"goto", "goto_v2", b"goto_v2", "ios_listen_background_image", b"ios_listen_background_image", "ios_listen_foreground_image", b"ios_listen_foreground_image", "ios_story_background_image", b"ios_story_background_image", "ios_story_foreground_image", b"ios_story_foreground_image", "listen_background_image", b"listen_background_image", "listen_foreground_image", b"listen_foreground_image", "story_background_image", b"story_background_image", "story_foreground_image", b"story_foreground_image", "url", b"url", "url_v2", b"url_v2"]) -> None: ...

global___TopLeft = TopLeft



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PGCAnyModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSINESS_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    VIEW_INFO_FIELD_NUMBER: builtins.int
    PLAY_EXT_CONF_FIELD_NUMBER: builtins.int
    PLAY_EXT_INFO_FIELD_NUMBER: builtins.int
    @property
    def business(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayViewBusinessInfo: ...
    @property
    def event(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.Event: ...
    @property
    def view_info(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.ViewInfo: ...
    @property
    def play_ext_conf(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayAbilityExtConf: ...
    @property
    def play_ext_info(self) -> bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayExtInfo: ...
    def __init__(
        self,
        *,
        business: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayViewBusinessInfo | None = ...,
        event: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.Event | None = ...,
        view_info: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.ViewInfo | None = ...,
        play_ext_conf: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayAbilityExtConf | None = ...,
        play_ext_info: bilireq.grpc.protos.bilibili.pgc.gateway.player.v2.playurl_pb2.PlayExtInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["business", b"business", "event", b"event", "play_ext_conf", b"play_ext_conf", "play_ext_info", b"play_ext_info", "view_info", b"view_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "event", b"event", "play_ext_conf", b"play_ext_conf", "play_ext_info", b"play_ext_info", "view_info", b"view_info"]) -> None: ...

global___PGCAnyModel = PGCAnyModel



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FeedModeValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    def __init__(
        self,
        *,
        value: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___FeedModeValue = FeedModeValue

@typing_extensions.final
class PegasusAutoPlay(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINGLE_FIELD_NUMBER: builtins.int
    DOUBLE_FIELD_NUMBER: builtins.int
    SINGLE_AFFECTED_BY_SERVER_SIDE_FIELD_NUMBER: builtins.int
    DOUBLE_AFFECTED_BY_SERVER_SIDE_FIELD_NUMBER: builtins.int
    @property
    def single(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def double(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def single_affected_by_server_side(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def double_affected_by_server_side(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        single: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        double: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        single_affected_by_server_side: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        double_affected_by_server_side: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["double", b"double", "double_affected_by_server_side", b"double_affected_by_server_side", "single", b"single", "single_affected_by_server_side", b"single_affected_by_server_side"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["double", b"double", "double_affected_by_server_side", b"double_affected_by_server_side", "single", b"single", "single_affected_by_server_side", b"single_affected_by_server_side"]) -> None: ...

global___PegasusAutoPlay = PegasusAutoPlay

@typing_extensions.final
class PegasusColumnValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    AFFECTED_BY_SERVER_SIDE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def affected_by_server_side(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        value: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        affected_by_server_side: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["affected_by_server_side", b"affected_by_server_side", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["affected_by_server_side", b"affected_by_server_side", "value", b"value"]) -> None: ...

global___PegasusColumnValue = PegasusColumnValue

@typing_extensions.final
class PegasusDeviceConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    AUTO_PLAY_FIELD_NUMBER: builtins.int
    @property
    def column(self) -> global___PegasusColumnValue:
        """"""
    @property
    def mode(self) -> global___FeedModeValue:
        """"""
    @property
    def auto_play(self) -> global___PegasusAutoPlay:
        """"""
    def __init__(
        self,
        *,
        column: global___PegasusColumnValue | None = ...,
        mode: global___FeedModeValue | None = ...,
        auto_play: global___PegasusAutoPlay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_play", b"auto_play", "column", b"column", "mode", b"mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_play", b"auto_play", "column", b"column", "mode", b"mode"]) -> None: ...

global___PegasusDeviceConfig = PegasusDeviceConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Business:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BusinessEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Business.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _Business.ValueType  # 0
    """未知类型"""
    STORY: _Business.ValueType  # 1
    """story业务"""

class Business(_Business, metaclass=_BusinessEnumTypeWrapper):
    """业务类型"""

UNKNOWN: Business.ValueType  # 0
"""未知类型"""
STORY: Business.ValueType  # 1
"""story业务"""
global___Business = Business

class _CodeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CodeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NOCODE: _CodeType.ValueType  # 0
    """默认"""
    CODE264: _CodeType.ValueType  # 1
    """H.264"""
    CODE265: _CodeType.ValueType  # 2
    """H.265"""
    CODEAV1: _CodeType.ValueType  # 3
    """av1"""

class CodeType(_CodeType, metaclass=_CodeTypeEnumTypeWrapper):
    """编码类型"""

NOCODE: CodeType.ValueType  # 0
"""默认"""
CODE264: CodeType.ValueType  # 1
"""H.264"""
CODE265: CodeType.ValueType  # 2
"""H.265"""
CODEAV1: CodeType.ValueType  # 3
"""av1"""
global___CodeType = CodeType

class _ConfType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ConfTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ConfType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoType: _ConfType.ValueType  # 0
    """"""
    FLIPCONF: _ConfType.ValueType  # 1
    """镜像反转"""
    CASTCONF: _ConfType.ValueType  # 2
    """视频投屏"""
    FEEDBACK: _ConfType.ValueType  # 3
    """反馈"""
    SUBTITLE: _ConfType.ValueType  # 4
    """字幕"""
    PLAYBACKRATE: _ConfType.ValueType  # 5
    """播放速度"""
    TIMEUP: _ConfType.ValueType  # 6
    """定时停止播放"""
    PLAYBACKMODE: _ConfType.ValueType  # 7
    """播放方式"""
    SCALEMODE: _ConfType.ValueType  # 8
    """画面尺寸"""
    BACKGROUNDPLAY: _ConfType.ValueType  # 9
    """后台播放"""
    LIKE: _ConfType.ValueType  # 10
    """顶"""
    DISLIKE: _ConfType.ValueType  # 11
    """踩"""
    COIN: _ConfType.ValueType  # 12
    """投币"""
    ELEC: _ConfType.ValueType  # 13
    """充电"""
    SHARE: _ConfType.ValueType  # 14
    """分享"""
    SCREENSHOT: _ConfType.ValueType  # 15
    """截图"""
    LOCKSCREEN: _ConfType.ValueType  # 16
    """锁屏"""
    RECOMMEND: _ConfType.ValueType  # 17
    """推荐"""
    PLAYBACKSPEED: _ConfType.ValueType  # 18
    """倍速"""
    DEFINITION: _ConfType.ValueType  # 19
    """清晰度"""
    SELECTIONS: _ConfType.ValueType  # 20
    """选集"""
    NEXT: _ConfType.ValueType  # 21
    """下一集"""
    EDITDM: _ConfType.ValueType  # 22
    """编辑弹幕"""
    SMALLWINDOW: _ConfType.ValueType  # 23
    """小窗"""
    SHAKE: _ConfType.ValueType  # 24
    """播放震动"""
    OUTERDM: _ConfType.ValueType  # 25
    """外层面板弹幕设置"""
    INNERDM: _ConfType.ValueType  # 26
    """三点内弹幕设置"""
    PANORAMA: _ConfType.ValueType  # 27
    """全景"""
    DOLBY: _ConfType.ValueType  # 28
    """杜比"""
    COLORFILTER: _ConfType.ValueType  # 29
    """颜色滤镜"""

class ConfType(_ConfType, metaclass=_ConfTypeEnumTypeWrapper):
    """设置类型"""

NoType: ConfType.ValueType  # 0
""""""
FLIPCONF: ConfType.ValueType  # 1
"""镜像反转"""
CASTCONF: ConfType.ValueType  # 2
"""视频投屏"""
FEEDBACK: ConfType.ValueType  # 3
"""反馈"""
SUBTITLE: ConfType.ValueType  # 4
"""字幕"""
PLAYBACKRATE: ConfType.ValueType  # 5
"""播放速度"""
TIMEUP: ConfType.ValueType  # 6
"""定时停止播放"""
PLAYBACKMODE: ConfType.ValueType  # 7
"""播放方式"""
SCALEMODE: ConfType.ValueType  # 8
"""画面尺寸"""
BACKGROUNDPLAY: ConfType.ValueType  # 9
"""后台播放"""
LIKE: ConfType.ValueType  # 10
"""顶"""
DISLIKE: ConfType.ValueType  # 11
"""踩"""
COIN: ConfType.ValueType  # 12
"""投币"""
ELEC: ConfType.ValueType  # 13
"""充电"""
SHARE: ConfType.ValueType  # 14
"""分享"""
SCREENSHOT: ConfType.ValueType  # 15
"""截图"""
LOCKSCREEN: ConfType.ValueType  # 16
"""锁屏"""
RECOMMEND: ConfType.ValueType  # 17
"""推荐"""
PLAYBACKSPEED: ConfType.ValueType  # 18
"""倍速"""
DEFINITION: ConfType.ValueType  # 19
"""清晰度"""
SELECTIONS: ConfType.ValueType  # 20
"""选集"""
NEXT: ConfType.ValueType  # 21
"""下一集"""
EDITDM: ConfType.ValueType  # 22
"""编辑弹幕"""
SMALLWINDOW: ConfType.ValueType  # 23
"""小窗"""
SHAKE: ConfType.ValueType  # 24
"""播放震动"""
OUTERDM: ConfType.ValueType  # 25
"""外层面板弹幕设置"""
INNERDM: ConfType.ValueType  # 26
"""三点内弹幕设置"""
PANORAMA: ConfType.ValueType  # 27
"""全景"""
DOLBY: ConfType.ValueType  # 28
"""杜比"""
COLORFILTER: ConfType.ValueType  # 29
"""颜色滤镜"""
global___ConfType = ConfType

class _Group:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GroupEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Group.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UnknownGroup: _Group.ValueType  # 0
    """"""
    A: _Group.ValueType  # 1
    """"""
    B: _Group.ValueType  # 2
    """"""
    C: _Group.ValueType  # 3
    """"""

class Group(_Group, metaclass=_GroupEnumTypeWrapper):
    """"""

UnknownGroup: Group.ValueType  # 0
""""""
A: Group.ValueType  # 1
""""""
B: Group.ValueType  # 2
""""""
C: Group.ValueType  # 3
""""""
global___Group = Group

class _PlayErr:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayErrEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayErr.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoErr: _PlayErr.ValueType  # 0
    """"""
    WithMultiDeviceLoginErr: _PlayErr.ValueType  # 1
    """管控类型的错误码"""

class PlayErr(_PlayErr, metaclass=_PlayErrEnumTypeWrapper):
    """错误码"""

NoErr: PlayErr.ValueType  # 0
""""""
WithMultiDeviceLoginErr: PlayErr.ValueType  # 1
"""管控类型的错误码"""
global___PlayErr = PlayErr

class _PlayLimitCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayLimitCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayLimitCode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PLCUnkown: _PlayLimitCode.ValueType  # 0
    """"""
    PLCUgcNotPayed: _PlayLimitCode.ValueType  # 1
    """"""

class PlayLimitCode(_PlayLimitCode, metaclass=_PlayLimitCodeEnumTypeWrapper):
    """"""

PLCUnkown: PlayLimitCode.ValueType  # 0
""""""
PLCUgcNotPayed: PlayLimitCode.ValueType  # 1
""""""
global___PlayLimitCode = PlayLimitCode

class _VideoType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown_VALUE: _VideoType.ValueType  # 0
    """"""
    FLV_VALUE: _VideoType.ValueType  # 1
    """flv格式"""
    DASH_VALUE: _VideoType.ValueType  # 2
    """dash格式"""
    MP4_VALUE: _VideoType.ValueType  # 3
    """mp4格式"""

class VideoType(_VideoType, metaclass=_VideoTypeEnumTypeWrapper):
    """视频类型"""

Unknown_VALUE: VideoType.ValueType  # 0
""""""
FLV_VALUE: VideoType.ValueType  # 1
"""flv格式"""
DASH_VALUE: VideoType.ValueType  # 2
"""dash格式"""
MP4_VALUE: VideoType.ValueType  # 3
"""mp4格式"""
global___VideoType = VideoType

@typing_extensions.final
class AB(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GLANCE_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    @property
    def glance(self) -> global___Glance:
        """"""
    group: builtins.int
    """"""
    def __init__(
        self,
        *,
        glance: global___Glance | None = ...,
        group: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["glance", b"glance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["glance", b"glance", "group", b"group"]) -> None: ...

global___AB = AB

@typing_extensions.final
class ArcConf(google.protobuf.message.Message):
    """配置项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_SUPPORT_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXTRA_CONTENT_FIELD_NUMBER: builtins.int
    is_support: builtins.bool
    """是否支持"""
    disabled: builtins.bool
    """"""
    @property
    def extra_content(self) -> global___ExtraContent:
        """"""
    def __init__(
        self,
        *,
        is_support: builtins.bool = ...,
        disabled: builtins.bool = ...,
        extra_content: global___ExtraContent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra_content", b"extra_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled", "extra_content", b"extra_content", "is_support", b"is_support"]) -> None: ...

global___ArcConf = ArcConf

@typing_extensions.final
class Chronos(google.protobuf.message.Message):
    """Chronos灰度管理"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MD5_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    md5: builtins.str
    """资源md5"""
    file: builtins.str
    """资源文件"""
    def __init__(
        self,
        *,
        md5: builtins.str = ...,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "md5", b"md5"]) -> None: ...

global___Chronos = Chronos

@typing_extensions.final
class ButtonStyle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    jump_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        bg_color: builtins.str = ...,
        jump_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "jump_link", b"jump_link", "text", b"text", "text_color", b"text_color"]) -> None: ...

global___ButtonStyle = ButtonStyle

@typing_extensions.final
class CloudConf(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_FIELD_NUMBER: builtins.int
    CONF_TYPE_FIELD_NUMBER: builtins.int
    FIELD_VALUE_FIELD_NUMBER: builtins.int
    CONF_VALUE_FIELD_NUMBER: builtins.int
    show: builtins.bool
    """是否展示功能"""
    conf_type: global___ConfType.ValueType
    """设置类型"""
    @property
    def field_value(self) -> global___FieldValue:
        """"""
    @property
    def conf_value(self) -> global___ConfValue:
        """"""
    def __init__(
        self,
        *,
        show: builtins.bool = ...,
        conf_type: global___ConfType.ValueType = ...,
        field_value: global___FieldValue | None = ...,
        conf_value: global___ConfValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conf_value", b"conf_value", "field_value", b"field_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conf_type", b"conf_type", "conf_value", b"conf_value", "field_value", b"field_value", "show", b"show"]) -> None: ...

global___CloudConf = CloudConf

@typing_extensions.final
class ConfValue(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SWITCH_VAL_FIELD_NUMBER: builtins.int
    SELECTED_VAL_FIELD_NUMBER: builtins.int
    switch_val: builtins.bool
    """"""
    selected_val: builtins.int
    """"""
    def __init__(
        self,
        *,
        switch_val: builtins.bool = ...,
        selected_val: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["selected_val", b"selected_val", "switch_val", b"switch_val", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["selected_val", b"selected_val", "switch_val", b"switch_val", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value", b"value"]) -> typing_extensions.Literal["switch_val", "selected_val"] | None: ...

global___ConfValue = ConfValue

@typing_extensions.final
class DashItem(google.protobuf.message.Message):
    """dash条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BASEURL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    WIDEVINE_PSSH_FIELD_NUMBER: builtins.int
    id: builtins.int
    """清晰度"""
    baseUrl: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    bandwidth: builtins.int
    """带宽"""
    codecid: builtins.int
    """编码id"""
    md5: builtins.str
    """md5"""
    size: builtins.int
    """大小"""
    frame_rate: builtins.str
    """帧率"""
    widevine_pssh: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        baseUrl: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: builtins.str = ...,
        size: builtins.int = ...,
        frame_rate: builtins.str = ...,
        widevine_pssh: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url", b"backup_url", "bandwidth", b"bandwidth", "baseUrl", b"baseUrl", "codecid", b"codecid", "frame_rate", b"frame_rate", "id", b"id", "md5", b"md5", "size", b"size", "widevine_pssh", b"widevine_pssh"]) -> None: ...

global___DashItem = DashItem

@typing_extensions.final
class DashVideo(google.protobuf.message.Message):
    """dash视频流"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    AUDIOID_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    WIDEVINE_PSSH_FIELD_NUMBER: builtins.int
    base_url: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    bandwidth: builtins.int
    """带宽"""
    codecid: builtins.int
    """编码id"""
    md5: builtins.str
    """md5"""
    size: builtins.int
    """大小"""
    audioId: builtins.int
    """伴音质量id"""
    no_rexcode: builtins.bool
    """是否非全二压"""
    frame_rate: builtins.str
    """码率"""
    width: builtins.int
    """宽度"""
    height: builtins.int
    """高度"""
    widevine_pssh: builtins.str
    """"""
    def __init__(
        self,
        *,
        base_url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: builtins.str = ...,
        size: builtins.int = ...,
        audioId: builtins.int = ...,
        no_rexcode: builtins.bool = ...,
        frame_rate: builtins.str = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        widevine_pssh: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audioId", b"audioId", "backup_url", b"backup_url", "bandwidth", b"bandwidth", "base_url", b"base_url", "codecid", b"codecid", "frame_rate", b"frame_rate", "height", b"height", "md5", b"md5", "no_rexcode", b"no_rexcode", "size", b"size", "widevine_pssh", b"widevine_pssh", "width", b"width"]) -> None: ...

global___DashVideo = DashVideo

@typing_extensions.final
class DolbyItem(google.protobuf.message.Message):
    """杜比伴音信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DolbyItem._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: DolbyItem._Type.ValueType  # 0
        """NONE"""
        COMMON: DolbyItem._Type.ValueType  # 1
        """普通杜比音效"""
        ATMOS: DolbyItem._Type.ValueType  # 2
        """全景杜比音效"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    NONE: DolbyItem.Type.ValueType  # 0
    """NONE"""
    COMMON: DolbyItem.Type.ValueType  # 1
    """普通杜比音效"""
    ATMOS: DolbyItem.Type.ValueType  # 2
    """全景杜比音效"""

    TYPE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    type: global___DolbyItem.Type.ValueType
    """杜比类型"""
    @property
    def audio(self) -> global___DashItem:
        """音频流"""
    def __init__(
        self,
        *,
        type: global___DolbyItem.Type.ValueType = ...,
        audio: global___DashItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "type", b"type"]) -> None: ...

global___DolbyItem = DolbyItem

@typing_extensions.final
class Event(google.protobuf.message.Message):
    """事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHAKE_FIELD_NUMBER: builtins.int
    @property
    def shake(self) -> global___Shake:
        """震动"""
    def __init__(
        self,
        *,
        shake: global___Shake | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["shake", b"shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["shake", b"shake"]) -> None: ...

global___Event = Event

@typing_extensions.final
class ExtraContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_REASON_FIELD_NUMBER: builtins.int
    DISABLED_CODE_FIELD_NUMBER: builtins.int
    disabled_reason: builtins.str
    """"""
    disabled_code: builtins.int
    """"""
    def __init__(
        self,
        *,
        disabled_reason: builtins.str = ...,
        disabled_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled_code", b"disabled_code", "disabled_reason", b"disabled_reason"]) -> None: ...

global___ExtraContent = ExtraContent

@typing_extensions.final
class FieldValue(google.protobuf.message.Message):
    """配置字段值"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SWITCH_FIELD_NUMBER: builtins.int
    switch: builtins.bool
    """开关"""
    def __init__(
        self,
        *,
        switch: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["switch", b"switch", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["switch", b"switch", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value", b"value"]) -> typing_extensions.Literal["switch"] | None: ...

global___FieldValue = FieldValue

@typing_extensions.final
class FormatDescription(google.protobuf.message.Message):
    """清晰度描述"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NEW_DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_DESC_FIELD_NUMBER: builtins.int
    SUPERSCRIPT_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """清晰度"""
    format: builtins.str
    """清晰度格式"""
    description: builtins.str
    """清晰度描述"""
    new_description: builtins.str
    """新描述"""
    display_desc: builtins.str
    """选中态的清晰度描述"""
    superscript: builtins.str
    """选中态的清晰度描述的角标"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        description: builtins.str = ...,
        new_description: builtins.str = ...,
        display_desc: builtins.str = ...,
        superscript: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_desc", b"display_desc", "format", b"format", "new_description", b"new_description", "quality", b"quality", "superscript", b"superscript"]) -> None: ...

global___FormatDescription = FormatDescription

@typing_extensions.final
class Glance(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAN_WATCH_FIELD_NUMBER: builtins.int
    TIMES_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    can_watch: builtins.bool
    """"""
    times: builtins.int
    """"""
    duration: builtins.int
    """"""
    def __init__(
        self,
        *,
        can_watch: builtins.bool = ...,
        times: builtins.int = ...,
        duration: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_watch", b"can_watch", "duration", b"duration", "times", b"times"]) -> None: ...

global___Glance = Glance

@typing_extensions.final
class PlayAbilityConf(google.protobuf.message.Message):
    """禁用功能配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_PLAY_CONF_FIELD_NUMBER: builtins.int
    FLIP_CONF_FIELD_NUMBER: builtins.int
    CAST_CONF_FIELD_NUMBER: builtins.int
    FEEDBACK_CONF_FIELD_NUMBER: builtins.int
    SUBTITLE_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_CONF_FIELD_NUMBER: builtins.int
    TIME_UP_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_CONF_FIELD_NUMBER: builtins.int
    SCALE_MODE_CONF_FIELD_NUMBER: builtins.int
    LIKE_CONF_FIELD_NUMBER: builtins.int
    DISLIKE_CONF_FIELD_NUMBER: builtins.int
    COIN_CONF_FIELD_NUMBER: builtins.int
    ELEC_CONF_FIELD_NUMBER: builtins.int
    SHARE_CONF_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_CONF_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_CONF_FIELD_NUMBER: builtins.int
    RECOMMEND_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_CONF_FIELD_NUMBER: builtins.int
    DEFINITION_CONF_FIELD_NUMBER: builtins.int
    SELECTIONS_CONF_FIELD_NUMBER: builtins.int
    NEXT_CONF_FIELD_NUMBER: builtins.int
    EDIT_DM_CONF_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_CONF_FIELD_NUMBER: builtins.int
    SHAKE_CONF_FIELD_NUMBER: builtins.int
    OUTER_DM_CONF_FIELD_NUMBER: builtins.int
    INNERDMDISABLE_FIELD_NUMBER: builtins.int
    INNER_DM_CONF_FIELD_NUMBER: builtins.int
    DOLBY_CONF_FIELD_NUMBER: builtins.int
    COLOR_FILTER_CONF_FIELD_NUMBER: builtins.int
    @property
    def background_play_conf(self) -> global___CloudConf:
        """后台播放"""
    @property
    def flip_conf(self) -> global___CloudConf:
        """镜像反转"""
    @property
    def cast_conf(self) -> global___CloudConf:
        """投屏"""
    @property
    def feedback_conf(self) -> global___CloudConf:
        """反馈"""
    @property
    def subtitle_conf(self) -> global___CloudConf:
        """字幕"""
    @property
    def playback_rate_conf(self) -> global___CloudConf:
        """播放速度"""
    @property
    def time_up_conf(self) -> global___CloudConf:
        """定时停止"""
    @property
    def playback_mode_conf(self) -> global___CloudConf:
        """播放方式"""
    @property
    def scale_mode_conf(self) -> global___CloudConf:
        """画面尺寸"""
    @property
    def like_conf(self) -> global___CloudConf:
        """赞"""
    @property
    def dislike_conf(self) -> global___CloudConf:
        """踩"""
    @property
    def coin_conf(self) -> global___CloudConf:
        """投币"""
    @property
    def elec_conf(self) -> global___CloudConf:
        """充电"""
    @property
    def share_conf(self) -> global___CloudConf:
        """分享"""
    @property
    def screen_shot_conf(self) -> global___CloudConf:
        """截图"""
    @property
    def lock_screen_conf(self) -> global___CloudConf:
        """锁定"""
    @property
    def recommend_conf(self) -> global___CloudConf:
        """相关推荐"""
    @property
    def playback_speed_conf(self) -> global___CloudConf:
        """播放速度"""
    @property
    def definition_conf(self) -> global___CloudConf:
        """清晰度"""
    @property
    def selections_conf(self) -> global___CloudConf:
        """选集"""
    @property
    def next_conf(self) -> global___CloudConf:
        """下一集"""
    @property
    def edit_dm_conf(self) -> global___CloudConf:
        """编辑弹幕"""
    @property
    def small_window_conf(self) -> global___CloudConf:
        """小窗"""
    @property
    def shake_conf(self) -> global___CloudConf:
        """震动"""
    @property
    def outer_dm_conf(self) -> global___CloudConf:
        """外层面板弹幕设置"""
    @property
    def innerDmDisable(self) -> global___CloudConf:
        """三点内弹幕设置"""
    @property
    def inner_dm_conf(self) -> global___CloudConf:
        """一起看入口"""
    @property
    def dolby_conf(self) -> global___CloudConf:
        """杜比音效"""
    @property
    def color_filter_conf(self) -> global___CloudConf:
        """颜色滤镜"""
    def __init__(
        self,
        *,
        background_play_conf: global___CloudConf | None = ...,
        flip_conf: global___CloudConf | None = ...,
        cast_conf: global___CloudConf | None = ...,
        feedback_conf: global___CloudConf | None = ...,
        subtitle_conf: global___CloudConf | None = ...,
        playback_rate_conf: global___CloudConf | None = ...,
        time_up_conf: global___CloudConf | None = ...,
        playback_mode_conf: global___CloudConf | None = ...,
        scale_mode_conf: global___CloudConf | None = ...,
        like_conf: global___CloudConf | None = ...,
        dislike_conf: global___CloudConf | None = ...,
        coin_conf: global___CloudConf | None = ...,
        elec_conf: global___CloudConf | None = ...,
        share_conf: global___CloudConf | None = ...,
        screen_shot_conf: global___CloudConf | None = ...,
        lock_screen_conf: global___CloudConf | None = ...,
        recommend_conf: global___CloudConf | None = ...,
        playback_speed_conf: global___CloudConf | None = ...,
        definition_conf: global___CloudConf | None = ...,
        selections_conf: global___CloudConf | None = ...,
        next_conf: global___CloudConf | None = ...,
        edit_dm_conf: global___CloudConf | None = ...,
        small_window_conf: global___CloudConf | None = ...,
        shake_conf: global___CloudConf | None = ...,
        outer_dm_conf: global___CloudConf | None = ...,
        innerDmDisable: global___CloudConf | None = ...,
        inner_dm_conf: global___CloudConf | None = ...,
        dolby_conf: global___CloudConf | None = ...,
        color_filter_conf: global___CloudConf | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["background_play_conf", b"background_play_conf", "cast_conf", b"cast_conf", "coin_conf", b"coin_conf", "color_filter_conf", b"color_filter_conf", "definition_conf", b"definition_conf", "dislike_conf", b"dislike_conf", "dolby_conf", b"dolby_conf", "edit_dm_conf", b"edit_dm_conf", "elec_conf", b"elec_conf", "feedback_conf", b"feedback_conf", "flip_conf", b"flip_conf", "innerDmDisable", b"innerDmDisable", "inner_dm_conf", b"inner_dm_conf", "like_conf", b"like_conf", "lock_screen_conf", b"lock_screen_conf", "next_conf", b"next_conf", "outer_dm_conf", b"outer_dm_conf", "playback_mode_conf", b"playback_mode_conf", "playback_rate_conf", b"playback_rate_conf", "playback_speed_conf", b"playback_speed_conf", "recommend_conf", b"recommend_conf", "scale_mode_conf", b"scale_mode_conf", "screen_shot_conf", b"screen_shot_conf", "selections_conf", b"selections_conf", "shake_conf", b"shake_conf", "share_conf", b"share_conf", "small_window_conf", b"small_window_conf", "subtitle_conf", b"subtitle_conf", "time_up_conf", b"time_up_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_conf", b"background_play_conf", "cast_conf", b"cast_conf", "coin_conf", b"coin_conf", "color_filter_conf", b"color_filter_conf", "definition_conf", b"definition_conf", "dislike_conf", b"dislike_conf", "dolby_conf", b"dolby_conf", "edit_dm_conf", b"edit_dm_conf", "elec_conf", b"elec_conf", "feedback_conf", b"feedback_conf", "flip_conf", b"flip_conf", "innerDmDisable", b"innerDmDisable", "inner_dm_conf", b"inner_dm_conf", "like_conf", b"like_conf", "lock_screen_conf", b"lock_screen_conf", "next_conf", b"next_conf", "outer_dm_conf", b"outer_dm_conf", "playback_mode_conf", b"playback_mode_conf", "playback_rate_conf", b"playback_rate_conf", "playback_speed_conf", b"playback_speed_conf", "recommend_conf", b"recommend_conf", "scale_mode_conf", b"scale_mode_conf", "screen_shot_conf", b"screen_shot_conf", "selections_conf", b"selections_conf", "shake_conf", b"shake_conf", "share_conf", b"share_conf", "small_window_conf", b"small_window_conf", "subtitle_conf", b"subtitle_conf", "time_up_conf", b"time_up_conf"]) -> None: ...

global___PlayAbilityConf = PlayAbilityConf

@typing_extensions.final
class PlayArcConf(google.protobuf.message.Message):
    """播放控件稿件配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_PLAY_CONF_FIELD_NUMBER: builtins.int
    FLIP_CONF_FIELD_NUMBER: builtins.int
    CAST_CONF_FIELD_NUMBER: builtins.int
    FEEDBACK_CONF_FIELD_NUMBER: builtins.int
    SUBTITLE_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_CONF_FIELD_NUMBER: builtins.int
    TIME_UP_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_CONF_FIELD_NUMBER: builtins.int
    SCALE_MODE_CONF_FIELD_NUMBER: builtins.int
    LIKE_CONF_FIELD_NUMBER: builtins.int
    DISLIKE_CONF_FIELD_NUMBER: builtins.int
    COIN_CONF_FIELD_NUMBER: builtins.int
    ELEC_CONF_FIELD_NUMBER: builtins.int
    SHARE_CONF_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_CONF_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_CONF_FIELD_NUMBER: builtins.int
    RECOMMEND_CONF_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_CONF_FIELD_NUMBER: builtins.int
    DEFINITION_CONF_FIELD_NUMBER: builtins.int
    SELECTIONS_CONF_FIELD_NUMBER: builtins.int
    NEXT_CONF_FIELD_NUMBER: builtins.int
    EDIT_DM_CONF_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_CONF_FIELD_NUMBER: builtins.int
    SHAKE_CONF_FIELD_NUMBER: builtins.int
    OUTER_DM_CONF_FIELD_NUMBER: builtins.int
    INNER_DM_CONF_FIELD_NUMBER: builtins.int
    PANORAMA_CONF_FIELD_NUMBER: builtins.int
    DOLBY_CONF_FIELD_NUMBER: builtins.int
    SCREEN_RECORDING_CONF_FIELD_NUMBER: builtins.int
    COLOR_FILTER_CONF_FIELD_NUMBER: builtins.int
    @property
    def background_play_conf(self) -> global___ArcConf:
        """后台播放"""
    @property
    def flip_conf(self) -> global___ArcConf:
        """镜像反转"""
    @property
    def cast_conf(self) -> global___ArcConf:
        """投屏"""
    @property
    def feedback_conf(self) -> global___ArcConf:
        """反馈"""
    @property
    def subtitle_conf(self) -> global___ArcConf:
        """字幕"""
    @property
    def playback_rate_conf(self) -> global___ArcConf:
        """播放速度"""
    @property
    def time_up_conf(self) -> global___ArcConf:
        """定时停止"""
    @property
    def playback_mode_conf(self) -> global___ArcConf:
        """播放方式"""
    @property
    def scale_mode_conf(self) -> global___ArcConf:
        """画面尺寸"""
    @property
    def like_conf(self) -> global___ArcConf:
        """赞"""
    @property
    def dislike_conf(self) -> global___ArcConf:
        """踩"""
    @property
    def coin_conf(self) -> global___ArcConf:
        """投币"""
    @property
    def elec_conf(self) -> global___ArcConf:
        """充电"""
    @property
    def share_conf(self) -> global___ArcConf:
        """分享"""
    @property
    def screen_shot_conf(self) -> global___ArcConf:
        """截图"""
    @property
    def lock_screen_conf(self) -> global___ArcConf:
        """锁定"""
    @property
    def recommend_conf(self) -> global___ArcConf:
        """相关推荐"""
    @property
    def playback_speed_conf(self) -> global___ArcConf:
        """播放速度"""
    @property
    def definition_conf(self) -> global___ArcConf:
        """清晰度"""
    @property
    def selections_conf(self) -> global___ArcConf:
        """选集"""
    @property
    def next_conf(self) -> global___ArcConf:
        """下一集"""
    @property
    def edit_dm_conf(self) -> global___ArcConf:
        """编辑弹幕"""
    @property
    def small_window_conf(self) -> global___ArcConf:
        """小窗"""
    @property
    def shake_conf(self) -> global___ArcConf:
        """震动"""
    @property
    def outer_dm_conf(self) -> global___ArcConf:
        """外层面板弹幕设置"""
    @property
    def inner_dm_conf(self) -> global___ArcConf:
        """三点内弹幕设置"""
    @property
    def panorama_conf(self) -> global___ArcConf:
        """一起看入口"""
    @property
    def dolby_conf(self) -> global___ArcConf:
        """杜比音效"""
    @property
    def screen_recording_conf(self) -> global___ArcConf:
        """屏幕录制"""
    @property
    def color_filter_conf(self) -> global___ArcConf:
        """颜色滤镜"""
    def __init__(
        self,
        *,
        background_play_conf: global___ArcConf | None = ...,
        flip_conf: global___ArcConf | None = ...,
        cast_conf: global___ArcConf | None = ...,
        feedback_conf: global___ArcConf | None = ...,
        subtitle_conf: global___ArcConf | None = ...,
        playback_rate_conf: global___ArcConf | None = ...,
        time_up_conf: global___ArcConf | None = ...,
        playback_mode_conf: global___ArcConf | None = ...,
        scale_mode_conf: global___ArcConf | None = ...,
        like_conf: global___ArcConf | None = ...,
        dislike_conf: global___ArcConf | None = ...,
        coin_conf: global___ArcConf | None = ...,
        elec_conf: global___ArcConf | None = ...,
        share_conf: global___ArcConf | None = ...,
        screen_shot_conf: global___ArcConf | None = ...,
        lock_screen_conf: global___ArcConf | None = ...,
        recommend_conf: global___ArcConf | None = ...,
        playback_speed_conf: global___ArcConf | None = ...,
        definition_conf: global___ArcConf | None = ...,
        selections_conf: global___ArcConf | None = ...,
        next_conf: global___ArcConf | None = ...,
        edit_dm_conf: global___ArcConf | None = ...,
        small_window_conf: global___ArcConf | None = ...,
        shake_conf: global___ArcConf | None = ...,
        outer_dm_conf: global___ArcConf | None = ...,
        inner_dm_conf: global___ArcConf | None = ...,
        panorama_conf: global___ArcConf | None = ...,
        dolby_conf: global___ArcConf | None = ...,
        screen_recording_conf: global___ArcConf | None = ...,
        color_filter_conf: global___ArcConf | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["background_play_conf", b"background_play_conf", "cast_conf", b"cast_conf", "coin_conf", b"coin_conf", "color_filter_conf", b"color_filter_conf", "definition_conf", b"definition_conf", "dislike_conf", b"dislike_conf", "dolby_conf", b"dolby_conf", "edit_dm_conf", b"edit_dm_conf", "elec_conf", b"elec_conf", "feedback_conf", b"feedback_conf", "flip_conf", b"flip_conf", "inner_dm_conf", b"inner_dm_conf", "like_conf", b"like_conf", "lock_screen_conf", b"lock_screen_conf", "next_conf", b"next_conf", "outer_dm_conf", b"outer_dm_conf", "panorama_conf", b"panorama_conf", "playback_mode_conf", b"playback_mode_conf", "playback_rate_conf", b"playback_rate_conf", "playback_speed_conf", b"playback_speed_conf", "recommend_conf", b"recommend_conf", "scale_mode_conf", b"scale_mode_conf", "screen_recording_conf", b"screen_recording_conf", "screen_shot_conf", b"screen_shot_conf", "selections_conf", b"selections_conf", "shake_conf", b"shake_conf", "share_conf", b"share_conf", "small_window_conf", b"small_window_conf", "subtitle_conf", b"subtitle_conf", "time_up_conf", b"time_up_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_conf", b"background_play_conf", "cast_conf", b"cast_conf", "coin_conf", b"coin_conf", "color_filter_conf", b"color_filter_conf", "definition_conf", b"definition_conf", "dislike_conf", b"dislike_conf", "dolby_conf", b"dolby_conf", "edit_dm_conf", b"edit_dm_conf", "elec_conf", b"elec_conf", "feedback_conf", b"feedback_conf", "flip_conf", b"flip_conf", "inner_dm_conf", b"inner_dm_conf", "like_conf", b"like_conf", "lock_screen_conf", b"lock_screen_conf", "next_conf", b"next_conf", "outer_dm_conf", b"outer_dm_conf", "panorama_conf", b"panorama_conf", "playback_mode_conf", b"playback_mode_conf", "playback_rate_conf", b"playback_rate_conf", "playback_speed_conf", b"playback_speed_conf", "recommend_conf", b"recommend_conf", "scale_mode_conf", b"scale_mode_conf", "screen_recording_conf", b"screen_recording_conf", "screen_shot_conf", b"screen_shot_conf", "selections_conf", b"selections_conf", "shake_conf", b"shake_conf", "share_conf", b"share_conf", "small_window_conf", b"small_window_conf", "subtitle_conf", b"subtitle_conf", "time_up_conf", b"time_up_conf"]) -> None: ...

global___PlayArcConf = PlayArcConf

@typing_extensions.final
class PlayConfEditReply(google.protobuf.message.Message):
    """编辑播放界面配置-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PlayConfEditReply = PlayConfEditReply

@typing_extensions.final
class PlayConfEditReq(google.protobuf.message.Message):
    """编辑播放界面配置-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_CONF_FIELD_NUMBER: builtins.int
    @property
    def play_conf(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayConfState]:
        """播放界面配置"""
    def __init__(
        self,
        *,
        play_conf: collections.abc.Iterable[global___PlayConfState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_conf", b"play_conf"]) -> None: ...

global___PlayConfEditReq = PlayConfEditReq

@typing_extensions.final
class PlayConfReply(google.protobuf.message.Message):
    """获取播放界面配置-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_CONF_FIELD_NUMBER: builtins.int
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """播放控件用户自定义配置"""
    def __init__(
        self,
        *,
        play_conf: global___PlayAbilityConf | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_conf", b"play_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_conf", b"play_conf"]) -> None: ...

global___PlayConfReply = PlayConfReply

@typing_extensions.final
class PlayConfReq(google.protobuf.message.Message):
    """获取播放界面配置-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PlayConfReq = PlayConfReq

@typing_extensions.final
class PlayConfState(google.protobuf.message.Message):
    """播放界面配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONF_TYPE_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    FIELD_VALUE_FIELD_NUMBER: builtins.int
    CONF_VALUE_FIELD_NUMBER: builtins.int
    conf_type: global___ConfType.ValueType
    """设置类型"""
    show: builtins.bool
    """是否隐藏"""
    @property
    def field_value(self) -> global___FieldValue:
        """配置字段值"""
    @property
    def conf_value(self) -> global___ConfValue:
        """"""
    def __init__(
        self,
        *,
        conf_type: global___ConfType.ValueType = ...,
        show: builtins.bool = ...,
        field_value: global___FieldValue | None = ...,
        conf_value: global___ConfValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conf_value", b"conf_value", "field_value", b"field_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conf_type", b"conf_type", "conf_value", b"conf_value", "field_value", b"field_value", "show", b"show"]) -> None: ...

global___PlayConfState = PlayConfState

@typing_extensions.final
class PlayLimit(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    SUB_MESSAGE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    code: global___PlayLimitCode.ValueType
    """"""
    message: builtins.str
    """"""
    sub_message: builtins.str
    """"""
    @property
    def button(self) -> global___ButtonStyle:
        """"""
    def __init__(
        self,
        *,
        code: global___PlayLimitCode.ValueType = ...,
        message: builtins.str = ...,
        sub_message: builtins.str = ...,
        button: global___ButtonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "code", b"code", "message", b"message", "sub_message", b"sub_message"]) -> None: ...

global___PlayLimit = PlayLimit

@typing_extensions.final
class PlayURLReply(google.protobuf.message.Message):
    """视频地址-回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    TIMELENGTH_FIELD_NUMBER: builtins.int
    VIDEO_CODECID_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    VIDEO_PROJECT_FIELD_NUMBER: builtins.int
    DURL_FIELD_NUMBER: builtins.int
    DASH_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    UPGRADE_LIMIT_FIELD_NUMBER: builtins.int
    SUPPORT_FORMATS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """清晰的"""
    format: builtins.str
    """格式"""
    timelength: builtins.int
    """总时长(单位为ms)"""
    video_codecid: builtins.int
    """编码id"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    video_project: builtins.bool
    """是否支持投影"""
    @property
    def durl(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseUrl]:
        """分段视频流列表"""
    @property
    def dash(self) -> global___ResponseDash:
        """dash数据"""
    no_rexcode: builtins.int
    """是否非全二压"""
    @property
    def upgrade_limit(self) -> global___UpgradeLimit:
        """互动视频升级提示"""
    @property
    def support_formats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FormatDescription]:
        """清晰度描述列表"""
    type: global___VideoType.ValueType
    """视频格式"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        timelength: builtins.int = ...,
        video_codecid: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        video_project: builtins.bool = ...,
        durl: collections.abc.Iterable[global___ResponseUrl] | None = ...,
        dash: global___ResponseDash | None = ...,
        no_rexcode: builtins.int = ...,
        upgrade_limit: global___UpgradeLimit | None = ...,
        support_formats: collections.abc.Iterable[global___FormatDescription] | None = ...,
        type: global___VideoType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dash", b"dash", "upgrade_limit", b"upgrade_limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dash", b"dash", "durl", b"durl", "fnval", b"fnval", "fnver", b"fnver", "format", b"format", "no_rexcode", b"no_rexcode", "quality", b"quality", "support_formats", b"support_formats", "timelength", b"timelength", "type", b"type", "upgrade_limit", b"upgrade_limit", "video_codecid", b"video_codecid", "video_project", b"video_project"]) -> None: ...

global___PlayURLReply = PlayURLReply

@typing_extensions.final
class PlayURLReq(google.protobuf.message.Message):
    """视频地址-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    spmid: builtins.str
    """当前页spm"""
    from_spmid: builtins.str
    """上一页spm"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "download", b"download", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "from_spmid", b"from_spmid", "qn", b"qn", "spmid", b"spmid"]) -> None: ...

global___PlayURLReq = PlayURLReq

@typing_extensions.final
class PlayViewReply(google.protobuf.message.Message):
    """播放页信息-回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_INFO_FIELD_NUMBER: builtins.int
    PLAY_CONF_FIELD_NUMBER: builtins.int
    UPGRADE_LIMIT_FIELD_NUMBER: builtins.int
    CHRONOS_FIELD_NUMBER: builtins.int
    PLAY_ARC_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    AB_FIELD_NUMBER: builtins.int
    PLAY_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def video_info(self) -> global___VideoInfo:
        """视频流信息"""
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """播放控件用户自定义配置"""
    @property
    def upgrade_limit(self) -> global___UpgradeLimit:
        """互动视频升级提示"""
    @property
    def chronos(self) -> global___Chronos:
        """Chronos灰度管理"""
    @property
    def play_arc(self) -> global___PlayArcConf:
        """播放控件稿件配置"""
    @property
    def event(self) -> global___Event:
        """事件"""
    @property
    def ab(self) -> global___AB:
        """"""
    @property
    def play_limit(self) -> global___PlayLimit:
        """"""
    def __init__(
        self,
        *,
        video_info: global___VideoInfo | None = ...,
        play_conf: global___PlayAbilityConf | None = ...,
        upgrade_limit: global___UpgradeLimit | None = ...,
        chronos: global___Chronos | None = ...,
        play_arc: global___PlayArcConf | None = ...,
        event: global___Event | None = ...,
        ab: global___AB | None = ...,
        play_limit: global___PlayLimit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ab", b"ab", "chronos", b"chronos", "event", b"event", "play_arc", b"play_arc", "play_conf", b"play_conf", "play_limit", b"play_limit", "upgrade_limit", b"upgrade_limit", "video_info", b"video_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ab", b"ab", "chronos", b"chronos", "event", b"event", "play_arc", b"play_arc", "play_conf", b"play_conf", "play_limit", b"play_limit", "upgrade_limit", b"upgrade_limit", "video_info", b"video_info"]) -> None: ...

global___PlayViewReply = PlayViewReply

@typing_extensions.final
class PlayViewReq(google.protobuf.message.Message):
    """播放页信息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    VOICE_BALANCE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    spmid: builtins.str
    """当前页spm"""
    from_spmid: builtins.str
    """上一页spm"""
    teenagers_mode: builtins.int
    """青少年模式"""
    prefer_codec_type: global___CodeType.ValueType
    """编码"""
    business: global___Business.ValueType
    """业务类型"""
    voice_balance: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        teenagers_mode: builtins.int = ...,
        prefer_codec_type: global___CodeType.ValueType = ...,
        business: global___Business.ValueType = ...,
        voice_balance: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "business", b"business", "cid", b"cid", "download", b"download", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "from_spmid", b"from_spmid", "prefer_codec_type", b"prefer_codec_type", "qn", b"qn", "spmid", b"spmid", "teenagers_mode", b"teenagers_mode", "voice_balance", b"voice_balance"]) -> None: ...

global___PlayViewReq = PlayViewReq

@typing_extensions.final
class ProjectReply(google.protobuf.message.Message):
    """投屏地址-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def project(self) -> global___PlayURLReply: ...
    def __init__(
        self,
        *,
        project: global___PlayURLReply | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["project", b"project"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project", b"project"]) -> None: ...

global___ProjectReply = ProjectReply

@typing_extensions.final
class ProjectReq(google.protobuf.message.Message):
    """投屏地址-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    spmid: builtins.str
    """当前页spm"""
    from_spmid: builtins.str
    """上一页spm"""
    protocol: builtins.int
    """使用协议
    0:默认乐播 1:自建协议 2:云投屏 3:airplay
    """
    device_type: builtins.int
    """投屏设备
    0:默认其他 1:OTT设备
    """
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        protocol: builtins.int = ...,
        device_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "device_type", b"device_type", "download", b"download", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "from_spmid", b"from_spmid", "protocol", b"protocol", "qn", b"qn", "spmid", b"spmid"]) -> None: ...

global___ProjectReq = ProjectReq

@typing_extensions.final
class ResponseDash(google.protobuf.message.Message):
    """dash数据"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def video(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """dash视频流"""
    @property
    def audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """dash伴音流"""
    def __init__(
        self,
        *,
        video: collections.abc.Iterable[global___DashItem] | None = ...,
        audio: collections.abc.Iterable[global___DashItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "video", b"video"]) -> None: ...

global___ResponseDash = ResponseDash

@typing_extensions.final
class ResponseUrl(google.protobuf.message.Message):
    """分段流条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    order: builtins.int
    """分段序号"""
    length: builtins.int
    """分段时长"""
    size: builtins.int
    """分段大小"""
    url: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    md5: builtins.str
    """md5"""
    def __init__(
        self,
        *,
        order: builtins.int = ...,
        length: builtins.int = ...,
        size: builtins.int = ...,
        url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        md5: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url", b"backup_url", "length", b"length", "md5", b"md5", "order", b"order", "size", b"size", "url", b"url"]) -> None: ...

global___ResponseUrl = ResponseUrl

@typing_extensions.final
class SegmentVideo(google.protobuf.message.Message):
    """分段视频流"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENT_FIELD_NUMBER: builtins.int
    @property
    def segment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseUrl]:
        """分段视频流列表"""
    def __init__(
        self,
        *,
        segment: collections.abc.Iterable[global___ResponseUrl] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["segment", b"segment"]) -> None: ...

global___SegmentVideo = SegmentVideo

@typing_extensions.final
class Shake(google.protobuf.message.Message):
    """震动"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    file: builtins.str
    """文件地址"""
    def __init__(
        self,
        *,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file"]) -> None: ...

global___Shake = Shake

@typing_extensions.final
class Stream(google.protobuf.message.Message):
    """视频流信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_INFO_FIELD_NUMBER: builtins.int
    DASH_VIDEO_FIELD_NUMBER: builtins.int
    SEGMENT_VIDEO_FIELD_NUMBER: builtins.int
    @property
    def stream_info(self) -> global___StreamInfo:
        """元数据"""
    @property
    def dash_video(self) -> global___DashVideo:
        """dash流"""
    @property
    def segment_video(self) -> global___SegmentVideo:
        """分段流"""
    def __init__(
        self,
        *,
        stream_info: global___StreamInfo | None = ...,
        dash_video: global___DashVideo | None = ...,
        segment_video: global___SegmentVideo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "dash_video", b"dash_video", "segment_video", b"segment_video", "stream_info", b"stream_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "dash_video", b"dash_video", "segment_video", b"segment_video", "stream_info", b"stream_info"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["dash_video", "segment_video"] | None: ...

global___Stream = Stream

@typing_extensions.final
class StreamInfo(google.protobuf.message.Message):
    """流媒体元数据"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ERR_CODE_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    NEED_VIP_FIELD_NUMBER: builtins.int
    NEED_LOGIN_FIELD_NUMBER: builtins.int
    INTACT_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    NEW_DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_DESC_FIELD_NUMBER: builtins.int
    SUPERSCRIPT_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """清晰度"""
    format: builtins.str
    """格式"""
    description: builtins.str
    """格式描述"""
    err_code: global___PlayErr.ValueType
    """错误码"""
    @property
    def limit(self) -> global___StreamLimit:
        """不满足条件信息"""
    need_vip: builtins.bool
    """是否需要vip"""
    need_login: builtins.bool
    """是否需要登录"""
    intact: builtins.bool
    """是否完整"""
    no_rexcode: builtins.bool
    """是否非全二压"""
    attribute: builtins.int
    """清晰度属性位"""
    new_description: builtins.str
    """新版格式描述"""
    display_desc: builtins.str
    """格式文字"""
    superscript: builtins.str
    """新版格式描述备注"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        description: builtins.str = ...,
        err_code: global___PlayErr.ValueType = ...,
        limit: global___StreamLimit | None = ...,
        need_vip: builtins.bool = ...,
        need_login: builtins.bool = ...,
        intact: builtins.bool = ...,
        no_rexcode: builtins.bool = ...,
        attribute: builtins.int = ...,
        new_description: builtins.str = ...,
        display_desc: builtins.str = ...,
        superscript: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limit", b"limit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "description", b"description", "display_desc", b"display_desc", "err_code", b"err_code", "format", b"format", "intact", b"intact", "limit", b"limit", "need_login", b"need_login", "need_vip", b"need_vip", "new_description", b"new_description", "no_rexcode", b"no_rexcode", "quality", b"quality", "superscript", b"superscript"]) -> None: ...

global___StreamInfo = StreamInfo

@typing_extensions.final
class StreamLimit(google.protobuf.message.Message):
    """清晰度不满足条件信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    msg: builtins.str
    """提示信息"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg", b"msg", "title", b"title", "uri", b"uri"]) -> None: ...

global___StreamLimit = StreamLimit

@typing_extensions.final
class UpgradeButton(google.protobuf.message.Message):
    """互动视频升级按钮信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    link: builtins.str
    """链接"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["link", b"link", "title", b"title"]) -> None: ...

global___UpgradeButton = UpgradeButton

@typing_extensions.final
class UpgradeLimit(google.protobuf.message.Message):
    """互动视频升级提示"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    code: builtins.int
    """错误码"""
    message: builtins.str
    """错误信息"""
    image: builtins.str
    """图片url"""
    @property
    def button(self) -> global___UpgradeButton:
        """按钮信息"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
        image: builtins.str = ...,
        button: global___UpgradeButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "code", b"code", "image", b"image", "message", b"message"]) -> None: ...

global___UpgradeLimit = UpgradeLimit

@typing_extensions.final
class VideoInfo(google.protobuf.message.Message):
    """视频url信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    TIMELENGTH_FIELD_NUMBER: builtins.int
    VIDEO_CODECID_FIELD_NUMBER: builtins.int
    STREAM_LIST_FIELD_NUMBER: builtins.int
    DASH_AUDIO_FIELD_NUMBER: builtins.int
    DOLBY_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """视频清晰度"""
    format: builtins.str
    """视频格式"""
    timelength: builtins.int
    """视频时长"""
    video_codecid: builtins.int
    """视频编码id"""
    @property
    def stream_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stream]:
        """视频流"""
    @property
    def dash_audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """伴音流"""
    @property
    def dolby(self) -> global___DolbyItem:
        """杜比伴音流"""
    @property
    def volume(self) -> global___VolumeInfo:
        """"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        timelength: builtins.int = ...,
        video_codecid: builtins.int = ...,
        stream_list: collections.abc.Iterable[global___Stream] | None = ...,
        dash_audio: collections.abc.Iterable[global___DashItem] | None = ...,
        dolby: global___DolbyItem | None = ...,
        volume: global___VolumeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dolby", b"dolby", "volume", b"volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dash_audio", b"dash_audio", "dolby", b"dolby", "format", b"format", "quality", b"quality", "stream_list", b"stream_list", "timelength", b"timelength", "video_codecid", b"video_codecid", "volume", b"volume"]) -> None: ...

global___VideoInfo = VideoInfo

@typing_extensions.final
class VolumeInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEASURED_I_FIELD_NUMBER: builtins.int
    MEASURED_LRA_FIELD_NUMBER: builtins.int
    MEASURED_TP_FIELD_NUMBER: builtins.int
    MEASURED_THRESHOLD_FIELD_NUMBER: builtins.int
    TARGET_OFFSET_FIELD_NUMBER: builtins.int
    TARGET_I_FIELD_NUMBER: builtins.int
    TARGET_TP_FIELD_NUMBER: builtins.int
    measured_i: builtins.float
    """"""
    measured_lra: builtins.float
    """"""
    measured_tp: builtins.float
    """"""
    measured_threshold: builtins.float
    """"""
    target_offset: builtins.float
    """"""
    target_i: builtins.float
    """"""
    target_tp: builtins.float
    """"""
    def __init__(
        self,
        *,
        measured_i: builtins.float = ...,
        measured_lra: builtins.float = ...,
        measured_tp: builtins.float = ...,
        measured_threshold: builtins.float = ...,
        target_offset: builtins.float = ...,
        target_i: builtins.float = ...,
        target_tp: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["measured_i", b"measured_i", "measured_lra", b"measured_lra", "measured_threshold", b"measured_threshold", "measured_tp", b"measured_tp", "target_i", b"target_i", "target_offset", b"target_offset", "target_tp", b"target_tp"]) -> None: ...

global___VolumeInfo = VolumeInfo
